{% extends "basic.html" %}
{% import "_macros.html" as macros with context %}

{% block content %}
{{ macros.adminka() }}

{# Page data #}
{% block page_content %}{% endblock %}

{{ macros.footer() }}
{% endblock %}