{% extends layout_template %}
{% import "_utils.html" as utils with context %}

{% block title %}{{ text.title }}{% endblock %}

{% block page_content %}
	{{ utils.make_upper(upper) }}
	<h1>{{ text.title }}</h1>

	<div class="page-main-content">
		{{ text.text_full |safe }}
		{% set label = current.other_settings_.get('label', '') -%}
		{% if label|length > 0 -%}
		<br><br>
		<div class="text-center">
			<span class="date">{{ label }}</span>
		</div>
		{%- endif %}
	</div>
{% endblock %}