body {
	height: 100%;
	padding: 0;
	background-color: hsl(210,33%,20%);
}
.container-fluid {
	padding: 0;
	height: 100%;
}

.admin-bar {
	padding: 6px 20px;
	text-align: center;
	background-color: hsl(0,0%,27%);
	color: white;
}
.admin-footer {
	text-align: center;
	height: 32px;
}
.admin-footer > span {
	padding: 4px;
	border: 1px solid hsl(0,50%,20%);
	border-radius: 6px;
	background-color: hsl(0,30%,45%);
	color: white;
}
.admin-footer > span > a {
	color: white;
}
.paipage-footer {
	padding: 32px 0px;
	text-align: center;
	color: hsl(210,30%,50%);
}

.menu-title-link, .menu-section-link {
	color: white;
}
.menu-title-link:hover, .menu-section-link:hover {
	color: hsl(0,0%,80%);
	text-decoration: underline;
}

.link-white {
	color: white;
}
.link-white:hover {
	color: hsl(0,0%,80%);
	text-decoration: underline;
}

.upheader {
	padding-top: 6px;
}
.upheader ~ h1 {
	margin-top: 0px;
}

.page-card-holder {
	display: block;
	position: relative;
	float: left;
	width: 100%;
}
.page-card {
	float: left;
	width: calc(100% - 20px);
	margin: 8px;
	padding: 0px 16px 16px 16px;
	background-color: hsla(210,33%,50%, 0.1);
	border: 1px solid hsl(210,33%,50%);
	border-radius: 6px;
}

@media (min-width: 992px) {
.page-card {
	width: calc(50% - 20px);
}
} /* Medium */


/* Common page - content */
.page-main {
	background-color: hsl(0,0%,97%);
	min-height: 64px;
}
.page-main-content {
	display: block;
	float: left;
	position: relative;
	width: 100%;
	padding-bottom: 32px;
	min-height: 64px;
}

