# Generated by Django 2.2.7 on 2020-06-11 17:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('paipage', '0002_auto_20200519_1746'),
    ]

    operations = [
        migrations.CreateModel(
            name='GlobalSetting',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(max_length=64, unique=True)),
                ('value', models.TextField(blank=True)),
                ('updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.AlterField(
            model_name='page',
            name='layout',
            field=models.CharField(blank=True, default='', max_length=256),
        ),
        migrations.AlterField(
            model_name='page',
            name='template',
            field=models.CharField(blank=True, default='', max_length=256),
        ),
    ]
