__title__ = 'PaiPaige Primary plugin'
__version__ = '1.0'
__license__ = 'GPL-3.0'
__author__ = 'AivanF'
__copyright__ = 'Copyright 2020, AivanF'
__contact__ = 'projects@aivanf.com'
description = 'Defines Adminka, commonly used macros, and other basic things.'
