/* Common page - top menu */
.menu-top {
	background-color: hsl(210,33%,33%);
	color: white;
	padding: 8px 0px;
}
.menu-top-title {
	display: block;
	float: left;
	width: 100%;
	height: 50%;
	padding-top: 14px;
	padding-left: 14px;
	font-weight: bold;
	font-size: 32px;
}
.menu-top-content {
	display: block;
	float: left;
	width: 100%;
	padding-left: 16px;
}
.menu-top-section {
	font-size: 20px;
	display: inline-block;
	margin: 2px 8px;
	color: hsl(210,33%,100%);
}
.menu-top-section-selected {
	color: hsl(210,33%,80%);
	text-decoration: underline;
}
