<!DOCTYPE html>
<html lang="ru">
<head>
	<meta charset="UTF-8">
	<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
	<title>{% block title %}{% endblock %}</title>

	<script src="https://ajax.googleapis.com/ajax/libs/jquery/3.2.0/jquery.min.js"></script>

	<link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/css/bootstrap.min.css">
	<script src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/js/bootstrap.min.js"></script>

	<script src="/static/jquery.masonry.min.js"></script>

	{% block meta %}{% endblock %}

	{% for filename in config.common_css %}
		<link rel="stylesheet" href="/static/{{ filename }}">
	{% endfor %}
</head>
<body>
<script type="text/javascript">
	{% for key, value in scripted.items() -%}
	const {{ key }} = {{ value|safe_json|safe }};
	{% endfor %}
</script>
<div class="container-fluid">
	{% block content %}{% endblock %}
</div><!-- container-fluid -->
</body>
</html>