/* Common page - left menu */
.menu-left {
	color: white;
	min-height: 100%;
	padding: 0;
}
.menu-left-title {
	background-color: hsl(210,33%,33%);
	margin-bottom: 16px;
}
.menu-left-content {
	padding-left: 0;
	color: white;
}
.menu-left-content > ul {
	padding-left: 28px;
}
.menu-left-content > ul > li {
	margin-bottom: 6px;
}
/* Common page - content */
.page-main {
	min-height: 100%;
}