.admin-bar {
	margin-bottom: 16px;
	padding: 6px 20px;
	text-align: center;
	background-color: hsl(0,30%,35%);
	color: white;
}

.clickable {
	color: black;
}
.clickable:hover, .clickable.selected {
	text-decoration: underline;
	cursor: pointer;
	color: black;
}
.clickable:hover {
	background: rgba(255,255,63,0.3);
}
.selected > .clickable {
	background: rgba(127,255,63,0.3);
}
.clickable.selected {
	background: rgba(127,255,63,0.3);
}

#blind {
	position: absolute;
	top: 0;
	left: 0;
	height: 100%;
	width: 100%;
	opacity: 0.5;
	background-color: #f0f0ff;
	z-index: 100;
	display: none;
}

.blind-inner {
	top: 40%;
	margin-top: -60px;
}

.loader {
	z-index: 111;
	border: 16px solid #e0e0e0; /* Light grey f3f3f3 */
	border-top: 16px solid #337abb; /* Blue 3498db */
	border-radius: 50%;
	width: 120px;
	height: 120px;
	animation: spin 2s linear infinite;
	margin-left: auto;
	margin-right: auto;
}

@keyframes spin {
	0% { transform: rotate(0deg); }
	100% { transform: rotate(360deg); }
}


@media only screen and (min-width: 800px) {
	.all-inner {
	margin-left: auto;
		margin-right: auto;
		width: 50%;
	}
}

@media only screen and (min-width: 1220px) {
	.all-inner {
	margin-left: auto;
		margin-right: auto;
		width: 25%;
	}
}

.mymodal {
	display: none; /* Hidden by default */
	position: fixed; /* Stay in place */
	/* Site on top */
	/*z-index: 1;*/
	left: 0;
	top: 0;
	width: 100%; /* Full width */
	height: 100%; /* Full height */
	overflow: auto; /* Enable scroll if needed */
	background-color: rgb(0,0,0); /* Fallback color */
	background-color: rgba(0,0,0,0.4); /* Black w/ opacity */
	padding-top: 60px;
}
.mymodal-content {
	margin-left: auto;
	margin-right: auto;
	width: 75%;
}

/* Add Zoom Animation */
.animater {
	-webkit-animation: animatezoom 0.6s;
	animation: animatezoom 0.6s
}

@-webkit-keyframes animatezoom {
	from {-webkit-transform: scale(0)}
	to {-webkit-transform: scale(1)}
}

@keyframes animatezoom {
	from {transform: scale(0)}
	to {transform: scale(1)}
}

@media (min-width:780px) {
	.mymodal-content {
		margin-left: auto;
		margin-right: auto;
		width: 50%;
	}
}

@media (min-width:1024px) {
	.mymodal-content {
		margin-left: auto;
		margin-right: auto;
		width: 33%;
	}
}