# Generated by Django 2.2.13 on 2020-07-05 05:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('paipage', '0004_globalsetting_updated_by'),
    ]

    operations = [
        migrations.AddField(
            model_name='page',
            name='other_settings',
            field=models.TextField(default='{}'),
        ),
    ]
