__author__ = 'AivanF'
__copyright__ = 'Copyright 2020, AivanF'
__contact__ = 'projects@aivanf.com'

default_app_config = 'paipage.apps.PaiPaiConfig'

from .config import config, configure
from .templating import TemplateHandler
